'' *****************************
'' *  Debug_Lcd                *
'' *  (C) 2006 Parallax, Inc.  *
'' *****************************
''
'' Debugging wrapper for Serial_Lcd


OBJ

  lcd  : "serial_lcd"


PUB start(pin, baud, lines) : okay

'' Starts serial LCD object
'' -- returns true if all parameters okay

  okay := lcd.start(pin, baud, lines) 


PUB stop

'' Stops lcd object -- frees the pin (floats)

  lcd.stop

  
PUB putc(txbyte)

'' Send a byte to the terminal

  lcd.putc(txbyte)
  
  
PUB str(str_addr) | i

'' Print a zero-terminated string

  lcd.str(str_addr)


PUB dec(value) | i, z

'' Print a signed decimal number

  if value < 0                                          ' value negative
    -value                                              ' yes, make positive
    putc("-")                                           ' and print negative indicator

  i := 1_000_000_000                                    ' initialize divisor
  z~                                                    ' clear zero-pad flag

  repeat 10                                             ' max of 10 digits
    if value => i                                       ' digit in this position?
      putc(value / i + "0")                             ' yes, convert to ASCII
      value //= i                                       ' remove this digit
      z~~                                               ' set zero flag
    elseif z or i == 1                                  ' if already printed or last position
      putc("0")                                         '   print zero
    i /= 10                                             ' update divisor for next digit


PUB decf(value, width) | tval, field

'' Prints signed decimal value in fixed-width field 

  width #>= 1                                           ' must be at least 1
  tval := ||value                                       ' work with absolute
  field~                                                ' clear field

  repeat while tval > 0                                 ' count number of digits
    field++
    tval /= 10

  field #>= 1                                           ' min field width is 1
  if value < 0                                          ' if value is negative
    field++                                             '   bump field for neg sign indicator
  
  if field < width                                      ' need for space pad?
    repeat (width - field)                              ' yes
      putc(" ")                                         '   print space(s)

  dec(value)                                            ' print value
  

PUB hex(value, digits)

'' Print a hexadecimal number

  value <<= (8 - digits) << 2
  repeat digits
    putc(lookupz((value <-= 4) & $F : "0".."9","A".."F"))


PUB bin(value, digits)

'' Print a binary number

  value <<= 32 - digits
  repeat digits
    putc((value <-= 1) & 1 + "0")
    

PUB cls

'' Clears LCD and moves cursor to home (0, 0) position

  lcd.cls 


PUB home

'' Moves cursor to 0, 0

  lcd.home
  

PUB clrln(line)

'' Clears line

  lcd.clrln(line)
  

PUB newline

'' Moves cursor to next line, column 0; will wrap from line 3 to line 0

  lcd.newline


PUB gotoxy(col, line)

'' Moves cursor to col/line

  lcd.gotoxy(col, line)


PUB cursor(crsr_type)

'' Selects cursor type
''   0 : cursor off, blink off  
''   1 : cursor off, blink on   
''   2 : cursor on, blink off  
''   3 : cursor on, blink on

  lcd.cursor(crsr_type) 


PUB custom(char, chr_addr)

'' Installs custom character map

  lcd.custom(char, chr_addr)

      
PUB backlight(status)

'' Enable (1) or disable (0) LCD backlight

  lcd.backlight(status)

  